@@ -11,7 +11,9 @@ import publication
 import aws_cdk.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-gamelift", "1.49.0", __name__[0:-6], "aws-gamelift@1.49.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-gamelift", "1.51.0", __name__[0:-6], "aws-gamelift@1.51.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
